==> tag_1.0.0.zip: server/src/main/java/cn/com/qmth/scancloud/controller/scan/OmrTaskController.java <==
package cn.com.qmth.scancloud.controller.scan;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;

import cn.com.qmth.scancloud.bean.User;
import cn.com.qmth.scancloud.controller.BaseController;
import cn.com.qmth.scancloud.service.OmrTaskService;
import cn.com.qmth.scancloud.vo.task.TaskResultVo;
import cn.com.qmth.scancloud.vo.task.TaskSaveVo;
import cn.com.qmth.scancloud.vo.task.TaskStatusVo;
import cn.com.qmth.scancloud.vo.task.TaskVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import net.sf.json.JSONObject;

@RestController
@Api(tags = "识别对照任务接口")
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/scan/task/omr")
@Aac(strict = BOOL.FALSE, auth = BOOL.TRUE)
public class OmrTaskController extends BaseController {

    protected static final Logger log = LoggerFactory.getLogger(OmrTaskController.class);

    @Autowired
    private OmrTaskService taskService;
    @Autowired
    private OmrTaskService omrTaskService;
    
    @ApiOperation(value = "识别对照任务获取")
    @RequestMapping(value = "/get", method = RequestMethod.POST)
    public TaskVo get(@RequestParam Long examId) {
        User user = getAccessUser();
        TaskVo task = taskService.getTask(examId, user.getAccount());
        return task;
    }

    @ApiOperation(value = "识别对照任务提交")
    @RequestMapping(value = "/save", method = RequestMethod.POST)
    public TaskSaveVo save(@RequestBody TaskResultVo result) {
        User user = getAccessUser();
        return taskService.submitTask(result, user.getAccount());
    }

    @ApiOperation(value = "识别对照任务状态")
    @RequestMapping(value = "/status", method = RequestMethod.POST)
    public TaskStatusVo status(@RequestParam Long examId) {
        User user = getAccessUser();
        return taskService.getStatus(examId, false,user.getAccount());
    }
    
    @ApiOperation(value = "识别对照任务状态")
    @RequestMapping(value = "/release", method = RequestMethod.POST)
    public JSONObject release(@RequestParam Long examId) {
        User user = getAccessUser();
        omrTaskService.releaseByUser(examId, user.getAccount());
        JSONObject result = new JSONObject();
        result.accumulate("success", true);
        return result;
    }
}

==> tag_1.0.2.zip: server/src/main/java/cn/com/qmth/scancloud/controller/scan/OmrTaskController.java <==
package cn.com.qmth.scancloud.controller.scan;

import cn.com.qmth.scancloud.bean.User;
import cn.com.qmth.scancloud.controller.BaseController;
import cn.com.qmth.scancloud.service.OmrTaskService;
import cn.com.qmth.scancloud.vo.task.TaskResultVo;
import cn.com.qmth.scancloud.vo.task.TaskSaveVo;
import cn.com.qmth.scancloud.vo.task.TaskStatusVo;
import cn.com.qmth.scancloud.vo.task.TaskVo;
import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

@RestController
@Api(tags = "识别对照任务接口")
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/scan/task/omr")
@Aac(strict = BOOL.FALSE, auth = BOOL.TRUE)
public class OmrTaskController extends BaseController {

    protected static final Logger log = LoggerFactory.getLogger(OmrTaskController.class);

    @Autowired
    private OmrTaskService omrTaskService;

    @ApiOperation(value = "识别对照任务获取")
    @RequestMapping(value = "/get", method = RequestMethod.POST)
    public TaskVo get(@RequestParam Long examId) {
        User user = getAccessUser();
        return omrTaskService.getTask(examId, user.getAccount());
    }

    @ApiOperation(value = "识别对照任务提交")
    @RequestMapping(value = "/save", method = RequestMethod.POST)
    public TaskSaveVo save(@Validated @RequestBody TaskResultVo result) {
        User user = getAccessUser();
        return omrTaskService.submitTask(result, user);
    }

    @ApiOperation(value = "识别对照任务状态")
    @RequestMapping(value = "/status", method = RequestMethod.POST)
    public TaskStatusVo status(@RequestParam Long examId) {
        User user = getAccessUser();
        return omrTaskService.getStatus(examId, false, user.getAccount());
    }

    @ApiOperation(value = "识别对照任务状态")
    @RequestMapping(value = "/release", method = RequestMethod.POST)
    public Object release(@RequestParam Long examId) {
        User user = getAccessUser();
        omrTaskService.releaseByUser(examId, user.getAccount());
        return success(true);
    }
}
